/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import Image from "next/image";
import React, { type JSX } from "react";
import { NavItems } from "../config/NavItems";

/**
 * Renders the main React component.
 * @returns A JSX element.
 */
const Home = (): JSX.Element => {
  return (
    <main className="w-4/5 text-center max-w-4xl m-auto mt-16 mb-16 rounded-lg">
      <h1 className="text-4xl mb-2">{`NHCarrigan`}</h1>
      <Image
        alt="NHCarrigan"
        className="rounded-full m-auto"
        height={200}
        src="https://cdn.nhcarrigan.com/logo.png"
        width={200}
      />
      <p className="text-2xl">{`Software Engineering and Community Management Consulting Firm`}</p>
      <p className="mb-4">
        {`Welcome to the landing page for our organisation! Use the links below to navigate.
        If you are looking for information about Naomi `}
        <a className="underline" href="/naomi">{`see her landing page`}</a>{`.`}
      </p>
      <ul>
        {NavItems.map((item, index) => {
          return (
            <li className="mb-4" key={item.href}>
              <a
                href={item.href}
                rel={item.href.startsWith("http")
                  ? "noreferrer"
                  : ""}
                target={item.href.startsWith("http")
                  ? "_blank"
                  : "_self"}
              >
                {index % 2 === 1
                  ? "🩷"
                  : "🩵"} {item.text}{" "}
              </a>
            </li>
          );
        })}
      </ul>
    </main>
  );
};

export default Home;
